Learn R Programming

toro (version 0.1.0)

add_lat_lng_grid: Add a grid of latitude and longitude lines to the map

Description

Add a grid of latitude and longitude lines to the map

Usage

add_lat_lng_grid(map, grid_colour = "#000000")

Value

The map or map proxy object for chaining.

Arguments

map

The map or map proxy object.

grid_colour

The colour of the grid lines. Default is "#000000".

Examples

Run this code
map() |>
 add_lat_lng_grid()

Run the code above in your browser using DataLab