Learn R Programming

toro (version 0.1.0)

add_tiles_from_wms: Add an Image Server source to a toro map

Description

WIP.

Usage

add_tiles_from_wms(map, url, tile_id, as_image_layer = FALSE, ...)

Value

The updated map object.

Arguments

map

A toro map object or a map proxy object.

url

The URL of the ArcGIS Image Server.

...

Additional parameters for the Image Server source.