Skip to contents

Used by other toro control functions to remove controls from a panel.

Usage

remove_control_from_panel(proxy, panel_id, control_id)

Arguments

proxy

The map proxy object created by mapProxy().

panel_id

The ID of the control panel.

control_id

The ID of the control to remove from the panel.

Value

The map proxy object for chaining.