Add a circle layer to a map or map proxy
Usage
add_circle_layer(
map,
id,
source,
paint = NULL,
layout = NULL,
popup_column = NULL,
hover_column = NULL,
can_cluster = FALSE,
under_id = NULL,
filter = NULL,
...
)Arguments
- map
The map object or map proxy to which the layer will be added.
- id
A unique identifier for the layer.
- source
The data source for the layer, if not a GeoJSON, it will be converted.
- paint
A list of paint options for styling the layer. See
get_paint_options()for defaults and options.- layout
A list of layout options for the layer. See
get_layout_options()for defaults and options.- popup_column
The column name to use for popups. Default is
NULL.- hover_column
The column name to use for hover effects. Default is
NULL.- can_cluster
Whether the layer can be clustered. Default is
FALSE.- under_id
The ID of an layer already on the map to place this layer under. Default is
NULL.- filter
A filter expression to apply to the layer. Default is
NULL. Seeget_layer_filter()for more details on how to create filter expressions.- ...
Additional arguments to include in the layer definition.
clusterOptions: A list of options for clustering, if
can_clusterisTRUE. See the cluster vignette for details on available options.
Examples
# Load libraries
library(spData)
#> To access larger datasets in this package, install the spDataLarge
#> package with: `install.packages('spDataLarge',
#> repos='https://nowosad.github.io/drat/', type='source')`
library(sf)
nz_data <- spData::nz_height |>
sf::st_transform(4326)
map() |>
set_bounds(bounds = nz_data) |>
add_circle_layer(
id = "nz_elevation",
source = nz_data,
hover_column = "elevation"
)
map() |>
set_bounds(bounds = nz_data) |>
add_circle_layer(
id = "nz_elevation",
source = nz_data,
hover_column = "elevation",
paint = get_paint_options(
"circle",
options = list(
colour = get_column_steps(
"elevation",
c(3000),
c("grey", "black")
)
)
)
)