Learn R Programming

toro (version 0.1.0)

add_control_to_panel: Add a control to an existing control panel

Description

Used by other toro control functions to add controls to a panel.

Usage

add_control_to_panel(
  map,
  panel_id,
  control_type,
  control_options = list(),
  section_title = NULL,
  group_id = NULL
)

Value

The map or map proxy object for chaining.

Arguments

map

The map or map proxy object.

panel_id

ID of the target control panel.

control_type

Type of control ("timeline", "speed", "custom").

control_options

Control-specific options.

section_title

Optional section title for the control.

group_id

Optional ID of the group to add the control to.