Used by other toro control functions to add controls to a panel.
add_control_to_panel(
map,
panel_id,
control_type,
control_options = list(),
section_title = NULL,
group_id = NULL
)The map or map proxy object for chaining.
The map or map proxy object.
ID of the target control panel.
Type of control ("timeline", "speed", "custom").
Control-specific options.
Optional section title for the control.
Optional ID of the group to add the control to.