- map
The map object or map proxy to which the layer will be added.
- id
A unique identifier for the layer.
- type
The type of layer to add (e.g., "fill", "circle", "line").
Default is "fill".
- source
The data source for the layer, if not a GeoJSON, it will be converted.
- paint
A list of paint options for styling the layer. See get_paint_options()
for defaults and options.
- layout
A list of layout options for the layer. See get_layout_options() for defaults
and options.
- popup_column
The column name to use for popups. Default is NULL.
- hover_column
The column name to use for hover effects. Default is NULL.
- can_cluster
Whether the layer can be clustered. Default is FALSE.
- under_id
The ID of an layer already on the map to place this layer under.
Default is NULL.
- filter
A filter expression to apply to the layer. Default is NULL. See
get_layer_filter() for more details on how to create filter expressions.
- ...
Additional arguments to include in the layer definition.