Get a column from a dataset to use as a paint or layout option in a map layer
Source:R/get_column_values.R
get_column.RdAllows the column value to be used for styling features in a map layer.

R/get_column_values.R
get_column.RdAllows the column value to be used for styling features in a map layer.