Learn R Programming

toro (version 0.1.0)

get_column: Get a column from a dataset to use as a paint or layout option in a map layer

Description

Allows the column value to be used for styling features in a map layer.

Usage

get_column(column_name)

Value

List containing the paint or layout option to be set.

Arguments

column_name

String representing the name of the column to be used.

Examples

Run this code
get_column("opacity")
get_column("icon")
# Use in a paint property: list("circle-color" = get_column("color"))

Run the code above in your browser using DataLab