powered by
Allows the column value to be used for styling features in a map layer.
get_column(column_name)
List containing the paint or layout option to be set.
String representing the name of the column to be used.
get_column("opacity") get_column("icon") # Use in a paint property: list("circle-color" = get_column("color"))
Run the code above in your browser using DataLab