Learn R Programming

toro (version 0.1.0)

get_column_boolean: Get the value for a paint or layout option in a map layer based on a column boolean value

Description

Allows the data to be styled by the group option in the column.

Usage

get_column_boolean(column_name, true_value, false_value)

Value

List containing the paint or layout option to be set.

Arguments

column_name

String representing the name of the column to be used.

true_value

Value to use when the column value is TRUE.

false_value

Value to use when the column value is FALSE.

Examples

Run this code
get_column_boolean("group", "red", "grey")

Run the code above in your browser using DataLab