powered by
Allows the data to be styled by the group option in the column.
get_column_boolean(column_name, true_value, false_value)
List containing the paint or layout option to be set.
String representing the name of the column to be used.
Value to use when the column value is TRUE.
TRUE
Value to use when the column value is FALSE.
FALSE
get_column_boolean("group", "red", "grey")
Run the code above in your browser using DataLab