powered by
Allows the data to be styled by the group option in the column.
get_column_group(column_name, named_group_values, default_value = "#cccccc")
List containing the paint or layout option to be set.
String representing the name of the column to be used.
Vector of value strings named by the group values. The names of the vector should match the group values in the column.
String for the default value to use if no match is found. Default is "#cccccc".
get_column_group("group", c("A" = "red", "B" = "blue"), "grey") get_column_group("opacity", stats::setNames(c(0.3, 0.5), c("A", "B")), 0.6)
Run the code above in your browser using DataLab