Get the properties for a column in a map layer based on step breaks
Source:R/get_column_values.R
get_column_steps.RdAllows the data to be styled by the step breaks in the column.
Examples
get_column_steps("value", c(10, 20, 30), c("red", "orange", "yellow", "green"))
#> [[1]]
#> [1] "step"
#>
#> [[2]]
#> [[2]][[1]]
#> [1] "get"
#>
#> [[2]][[2]]
#> [1] "value"
#>
#>
#> [[3]]
#> [1] "red"
#>
#> [[4]]
#> [1] 10
#>
#> [[5]]
#> [1] "orange"
#>
#> [[6]]
#> [1] 20
#>
#> [[7]]
#> [1] "yellow"
#>
#> [[8]]
#> [1] 30
#>
#> [[9]]
#> [1] "green"
#>