Learn R Programming

toro (version 0.1.0)

get_column_steps: Get the properties for a column in a map layer based on step breaks

Description

Allows the data to be styled by the step breaks in the column.

Usage

get_column_steps(column_name, breaks, values)

Value

List containing the paint or layout option to be set.

Arguments

column_name

String representing the name of the column to be used.

breaks

Numeric vector of thresholds (must be sorted ascending).

values

Vector of values, length = length(breaks) + 1.

Examples

Run this code
get_column_steps("value", c(10, 20, 30), c("red", "orange", "yellow", "green"))

Run the code above in your browser using DataLab