powered by
Allows the data to be styled by the step breaks in the column.
get_column_steps(column_name, breaks, values)
List containing the paint or layout option to be set.
String representing the name of the column to be used.
Numeric vector of thresholds (must be sorted ascending).
Vector of values, length = length(breaks) + 1.
get_column_steps("value", c(10, 20, 30), c("red", "orange", "yellow", "green"))
Run the code above in your browser using DataLab