image_to_data_uri: Helper function to convert local image to data URI
Description
Helper function to convert local image to data URI
Usage
image_to_data_uri(image_path)
Value
A data URI string representing the image.
Arguments
- image_path
The file path to the local image.