Additional options to customize the map.
minZoom: Minimum zoom level (0-24). Default is 2.
maxZoom: Maximum zoom level (0-24). Default is 18.
clusterColour: The colour of the cluster circles. Default is "#808080".
loadedTiles: A character vector of tile ids to load, or a named list of tile options.
Full options: c("natgeo", "satellite", "topo", "terrain", "streets", "shaded", "lightgrey").
Default is c("lightgrey", "satellite").
initialTileLayer: The tile layer to use when the map is first loaded.
Default is NULL (the first layer in loadedTiles).
backgroundColour: The background colour of the map. Default is "#D0CFD4".
enable3D: Whether to enable 3D dragging/view. Default is FALSE.
initialLoadedLayers: A character vector of layer ids that should be loaded before the
initial map spinner is hidden. Default is NULL.
spinnerWhileBusy: Whether to show a spinner while the map is busy (e.g. loading tiles).
Default is FALSE.
busyLoaderBgColour: The background colour of the busy loader.
Default is "rgba(0, 0, 0, 0.2)".
busyLoaderColour: The colour of the busy loader. Default is "white".
initialLoaderBgColour: The background colour of the initial loader. Default is "white".
initialLoaderColour: The colour of the initial loader. Default is "black".
clusterOptions: A list of options for clustering, if can_cluster is TRUE.
See the cluster vignette
for details on available options.
attributionPosition: The position of the attribution control. Default is "bottom-right".