Used by other toro control functions to remove controls from a panel.
Arguments
- proxy
The map proxy object created by
mapProxy().- panel_id
The ID of the control panel.
- control_id
The ID of the control to remove from the panel.
Used by other toro control functions to remove controls from a panel.
The map proxy object created by mapProxy().
The ID of the control panel.
The ID of the control to remove from the panel.