Learn R Programming

toro (version 0.1.0)

remove_control_from_panel: Remove a control from a control panel

Description

Used by other toro control functions to remove controls from a panel.

Usage

remove_control_from_panel(proxy, panel_id, control_id)

Value

The map proxy object for chaining.

Arguments

proxy

The map proxy object created by mapProxy().

panel_id

The ID of the control panel.

control_id

The ID of the control to remove from the panel.